==> gnome-db-0.0.20.tar.gz: gnome-db-0.0.20/gda-mysql-server/gda-mysql-error.c <==
/* GNOME DB libary
 * Copyright (C) 1998,1999 Michael Lausch
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "gda-mysql-types.h"

#include "gda-mysql-error.h"

Gda_MYSQL_Error*
gda_mysql_error_new(void)
{
  Gda_MYSQL_Error* e = g_new0(Gda_MYSQL_Error, 1);
  return e;
}

void
gda_mysql_error_free(Gda_MYSQL_Error* e)
{
  if (e->description)
    g_free(e->description);
  if (e->source)
    g_free(e->source);
  if (e->sqlstate)
    g_free(e->sqlstate);
  if (e->native)
    g_free(e->native);
  if (e->helpfile)
    g_free(e->helpfile);
  if (e->helpctxt)
    g_free(e->helpctxt);
  g_free(e);
}


void
gda_mysql_error_make(Gda_MYSQL_Connection* cnc, gchar* where)
{
  Gda_MYSQL_Error* error = gda_mysql_error_new();
  gchar bfr[128];

  g_warning("Error at '%s': ", where);
  g_snprintf(bfr, sizeof(bfr), "S%d", mysql_errno(cnc->mysql));
  error->description = g_strdup(mysql_error(cnc->mysql));
  error->source = g_strdup("[MYSQL]");
  error->helpfile = 0;
  error->helpctxt = 0;
  error->sqlstate = g_strdup(bfr);
  error->native = g_strdup(error->description);
  cnc->errors = g_list_append(cnc->errors, error);
  g_warning("error->description = '%s'\n", error->description);
  g_warning("   sqlstate = '%s'\n", error->sqlstate);
  
}

==> gnome-db-0.0.91.tar.gz: gnome-db-0.0.91/gda-mysql-server/gda-mysql-error.c <==
/* GNOME DB libary
 * Copyright (C) 1998,1999 Michael Lausch
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "gda-mysql-types.h"
#include "gda-mysql-error.h"

Gda_MYSQL_Error*
gda_mysql_error_new(void)
{
  Gda_MYSQL_Error* e = g_new0(Gda_MYSQL_Error, 1);
  return e;
}

void
gda_mysql_error_free(Gda_MYSQL_Error* e)
{
  if (e->description)
    g_free(e->description);
  if (e->source)
    g_free(e->source);
  if (e->sqlstate)
    g_free(e->sqlstate);
  if (e->native)
    g_free(e->native);
  if (e->helpfile)
    g_free(e->helpfile);
  if (e->helpctxt)
    g_free(e->helpctxt);
  g_free(e);
}


void
gda_mysql_error_make(Gda_MYSQL_Connection* cnc, gchar* where)
{
  Gda_MYSQL_Error* error = gda_mysql_error_new();
  gchar bfr[128];

  g_warning("Error at '%s': ", where);
  g_snprintf(bfr, sizeof(bfr), "S%d", mysql_errno(cnc->mysql));
  error->description = g_strdup(mysql_error(cnc->mysql));
  error->source = g_strdup("[MYSQL]");
  error->helpfile = g_strdup("error");
  error->helpctxt = g_strdup("error");
  error->sqlstate = g_strdup(bfr);
  error->native = g_strdup(error->description);
  cnc->errors = g_list_append(cnc->errors, error);
  g_warning("error->description = '%s'\n", error->description);
  g_warning("   sqlstate = '%s'\n", error->sqlstate);
  
}
